#include <sstream>
#include <gtkmm.h>
#include "Define.h"
#include "GetProfile.h"
#include "WriteProfile.h"
#include "ManageThread.h"
#include "connect_vnc.h"

#define INIT_FILE "/.convnc.ini"

ConnectVnc::ConnectVnc()
{
	std::stringstream inifile;
	inifile << getenv("HOME");
	inifile << INIT_FILE;
	GetProfile get_profile(inifile.str());
	std::list< Glib::ustring > list_ustr;
	Glib::ustring buffer;
	std::stringstream setting;

	m_refTreeModel = Gtk::ListStore::create(m_ModelColumns);
	m_Combobox.set_model(m_refTreeModel);
	for(int i = 1; i < 6; i++){
		setting.str("");
		setting.clear(std::stringstream::goodbit);
		setting << "setting_";
		setting << std::dec << i;
		buffer = get_profile.getString(setting.str(), "name").c_str();
		Gtk::TreeModel::Row row = *(m_refTreeModel->append());
		row[m_ModelColumns.m_ColumnID] = i;
		row[m_ModelColumns.m_ColumnName] = buffer;

	}
	m_Combobox.pack_start(m_ModelColumns.m_ColumnID);
	m_Combobox.pack_start(m_ModelColumns.m_ColumnName);
	m_vbox.pack_start(m_Combobox);
	m_Ok.set_label("OK");
	m_Cancel.set_label("Cancel");
	m_hbox.pack_start(m_Ok);
	m_hbox.pack_start(m_Cancel);
	m_vbox.pack_start(m_hbox);

	add( m_vbox );
	m_Ok.signal_clicked().connect(sigc::mem_fun(*this, &ConnectVnc::clickOK));
	m_Cancel.signal_clicked().connect(sigc::mem_fun(*this, &ConnectVnc::clickCancel));
	m_Combobox.signal_show().connect(sigc::mem_fun(*this, &ConnectVnc::showCombobox));
	this->signal_show().connect(sigc::mem_fun(*this, &ConnectVnc::showWindow));
	show_all_children();
}

void ConnectVnc::executeCommand(std::string name)
{
	std::stringstream inifile;
	inifile << getenv("HOME");
	inifile << INIT_FILE;
	GetProfile get_profile(inifile.str());
	std::stringstream setting, command;
	setting << "setting_";
	setting << std::dec << get_profile.getInt("display_number", "current");
	ManageThread command_thread;
	for(int i = 0; i < 5; i++){
		command << name.c_str();
		command << std::dec << i + 1;
		if( get_profile.getString(setting.str(), command.str()).size() != 0 ){
			command_thread.getData().getData().commandString.push_back(get_profile.getString(setting.str(), command.str()));
		}
		command.str("");
		command.clear(std::stringstream::goodbit);
	}
	command_thread.run("./");
	command_thread.getControlThread().waitForCompletion();
}

void ConnectVnc::clickOK()
{
	std::stringstream inifile;
	inifile << getenv("HOME");
	inifile << INIT_FILE;
	WriteProfile write_profile(inifile.str());
	GetProfile get_profile(inifile.str());
	std::stringstream string_stream;
	string_stream << "setting_";
	string_stream << std::dec << m_Combobox.get_active_row_number() + 1;
	write_profile.writeInt("display_number", "current", m_Combobox.get_active_row_number() + 1);
	executeCommand("pre_command_");
	Gtk::MessageDialog dialog("起動します");
	dialog.run();
	if( m_ChangeVT.change() == OK ){
		ManageThread fbvnc;
		fbvnc.getData().getData().commandString.
				push_back(get_profile.getString(string_stream.str(), "fbvnc"));
		fbvnc.run("./");
		fbvnc.getControlThread().waitForCompletion();
		m_ChangeVT.cleanup();
	}
	executeCommand("post_command_");
}

void ConnectVnc::clickCancel()
{
	Gtk::Main::quit();
}

#include <iostream>
void ConnectVnc::showCombobox()
{
	std::stringstream inifile;
	inifile << getenv("HOME");
	inifile << INIT_FILE;
	GetProfile get_profile(inifile.str());
	std::stringstream string_stream;
	string_stream << "setting_" << get_profile.getInt("display_number", "current");
	Glib::ustring buffer = get_profile.getString(string_stream.str(), "name").c_str();
	m_Combobox.set_active(get_profile.getInt("display_number", "current") - 1);
}

void ConnectVnc::showWindow()
{
	int x, y, height, width, depth;
	Gdk::Window::get_default_root_window()->get_geometry(x, y, width, height, depth);
	int window_width, window_height;
	get_window()->get_size(window_width, window_height);
	get_window()->move((width - window_width) / 2, (height - window_height) / 2);
}
